@@ -1,14 +1,15 @@
 __name__             = 'pytwitch'
-__version__          = '0.0.6'
-__description__      = 'PyTwitch - Twitch Integration for Python'
+__version__          = '0.1.0'
+__description__      = 'PyTwitch - Easy Python integration of the Twitch (v2) API'
 
 __author__           = 'Daniel Hyldebrandt Hemmingsen'
 __author_email__     = 'daniel.h.hemmingsen@gmail.com'
-__uri__              = 'https://github.com/dhh-hss/pytwitch'
+__url__              = 'https://github.com/dhh-hss/pytwitch'
+__docs_url__         = 'http://pytwitch.readthedocs.org'
 
 __keywords__         = ['twitch','api','development']
 __install_requires__ = ['requests>=2.4.0']
-__classifiers__      = ['Development Status :: 1 - Planning',
+__classifiers__      = ['Development Status :: 4 - Beta',
     'Intended Audience :: Developers',
     'Natural Language :: English',
     'License :: OSI Approved :: MIT License',
